@@ -5,15 +5,18 @@
 See ``dir(unpythonic)`` and submodule docstrings for more.
 """
 
-__version__ = '0.7.0'
+__version__ = '0.8.1'
 
 from . import rc
 
+from .amb import *
 from .arity import *
 from .assignonce import *
 from .dynscope import *
 from .ec import *
 from .fun import *
+from .fup import *
+from .it import *
 from .let import *  # no guarantees on evaluation order (before Python 3.6), nice syntax
 
 # guaranteed evaluation order, clunky syntax
@@ -21,6 +24,7 @@ from .lispylet import let as ordered_let, letrec as ordered_letrec, \
                       dlet as ordered_dlet, dletrec as ordered_dletrec, \
                       blet as ordered_blet, bletrec as ordered_bletrec
 
+from .llist import *
 from .misc import *
 from .seq import *
 
@@ -45,11 +49,11 @@ def _init_tco():
         raise ValueError("Unknown TCO implementation '{}'".format(rc._tco_impl))
     _starimport(tco)
 
+# Modules that require reloading because their module-level initialization
+# performs some from-imports from the TCO module.
 def _init_fploop(reload=False):
     global fploop
     from . import fploop
-    # We must reload fploop, because its module-level initialization
-    # performs some from-imports from the TCO module.
     if reload:
         from importlib import reload
         fploop = reload(fploop)
